@@ -2,11 +2,11 @@
 # shellcheck disable=SC2034
 
 iso_name="gunivalent-ja"
-iso_label="GUNIVALENT_JA_23.06"
+iso_label="UVE_2306G"
 iso_publisher="RadioNewJapan"
-iso_application="UVGL Installation Drive"
-iso_version="23.06"
-install_dir="arch"
+iso_application="UVE Installation Drive"
+iso_version="23.06.1"
+install_dir="univa"
 bootmodes=('bios.syslinux.mbr' 'bios.syslinux.eltorito' 'uefi-x64.systemd-boot.esp' 'uefi-x64.systemd-boot.eltorito')
 arch="x86_64"
 pacman_conf="pacman.conf"
@@ -19,4 +19,5 @@ file_permissions=(
   ["/usr/local/bin/choose-mirror"]="0:0:755"
   ["/usr/local/bin/Installation_guide"]="0:0:755"
   ["/usr/local/bin/livecd-sound"]="0:0:755"
+  ["/usr/local/bin/univafirstrun.sh"]="0:0:755"
 )
