@@ -2,11 +2,11 @@
 # shellcheck disable=SC2034
 
 iso_name="uni3valent-en"
-iso_label="UNI3VALENT_EN_23.06"
+iso_label="UVE_2306I"
 iso_publisher="RadioNewJapan"
-iso_application="UVGL Installaton Drive"
-iso_version="23.06"
-install_dir="arch"
+iso_application="UVE Installaton Drive"
+iso_version="23.06.1"
+install_dir="univa"
 bootmodes=('bios.syslinux.mbr' 'bios.syslinux.eltorito' 'uefi-x64.systemd-boot.esp' 'uefi-x64.systemd-boot.eltorito')
 arch="x86_64"
 pacman_conf="pacman.conf"
